library(shiny)
source("./functions.R")
source("./ui.R")
source("./server.R")

app <- shinyApp(ui = ui, server = server)

runApp(app, launch.browser = F)

x <- "../jorge/I/bg_subtract_p.tif"
y <- "../jorge/I/bg_subtract_ca.tif"
dat1 <- read_tif(x, exclude_zero = FALSE, include_xy = TRUE)
dat2 <- read_tif(y, exclude_zero = FALSE, include_xy = TRUE)
dat <- join_tif(dat1, dat2, exclude_zero = TRUE) %>%
.[, .(x = I.x, y = I.y)]

dat %>%
predict_joint_density(dat, n = 100)

dat_density <- dat %>%
resample(0.1) %>%
get_joint_density(n = 100)

pred <- function(dat, dat_density) {
  x_spline <- smooth.spline(dat_density$x, dat_density$density)
  y_spline <- smooth.spline(dat_density$y, dat_density$density)
  dat[, density := (predict(x_spline, x)[[2]] *
    predict(y_spline, y)[[2]])
  ]
  return(dat)
}

dat %>%
pred(dat_density)

dat %>%
resample(0.1) %>%
predict_joint_density() %>%
ggplot(aes(x = x, y = y)) +
geom_jitter(
  aes(color = density),
  width = 0.5, height = 0.5
) +
scale_color_gradientn(
  colors = rev(c(terrain.colors(5)))
)

dat %>%
resample(0.05) %>%
predict_joint_density(50) %>%
draw_scatter(box = 0.1)