library("shiny")

notes <- div(
  h4("Note:"),
  p("Proper use of this tool should acknowledge the following assumptions"),
  em(
    "1. All images have minimal to no background (background substraction)."
  ),
  br(),
  em("2. Images to be correlated are pre-aligned (registration)."),
  br(),
  br(),
  style = "color: red"
)

files <- fluidRow(
  h4("File Menu:"),
  sliderInput(
    "nfiles",
    label = "Number of files",
    value = 1,
    min = 1,
    max = 4,
    step = 1
  ),
  uiOutput("file_selectors"),
  checkboxInput(
    "exclude_zero",
    label = "Exclude Zero",
    value = TRUE
  )
)

combine_histogram_menu <- conditionalPanel(
  condition = "input.show_histogram & input.nfiles >= 2",
  column(
    12,
    checkboxInput(
      "combine_hist",
      label = "Combine histogram",
      value = FALSE
    ),
    conditionalPanel(
      condition = "input.combine_hist",
      checkboxInput(
        "color_hist",
        label = "Color histogram",
        value = FALSE
      )
    ),
    conditionalPanel(
      condition = "input.color_hist",
      checkboxInput(
        "show_overall",
        label = "Add Overall",
        value = FALSE
      )
    )
  )
)
histogram_menu <- fluidRow(
  h4("Histogram Menu:"),
  column(
    4,
    checkboxInput(
      "show_histogram",
      label = "Show Histogram",
      value = FALSE
    ),
    conditionalPanel(
      condition = "input.show_histogram",
      checkboxInput(
        "show_boxplot",
        label = "Show Boxplot",
        value = FALSE
      ),
      combine_histogram_menu,
      downloadButton("histogramdata", "Histogram data"),
      br(),
      conditionalPanel(
        condition = "input.show_boxplot",
        downloadButton("boxdata", "Boxplot data")
      )
    ),

  ),
  conditionalPanel(
    condition = "input.show_histogram",
    column(
      8,
      sliderInput(
        "histbins",
        label = "Number of bins",
        value = 25,
        min = 25,
        max = 250,
        step = 5
      ),
      sliderInput(
        "smooth_factor",
        label = "Smoothness factor",
        value = 1,
        min = 1,
        max = 5,
        step = 0.5
      ),
      conditionalPanel(
        condition = "input.combine_hist & !input.color_hist",
        sliderInput(
          "npeaks",
          label = "Gaussian Peaks",
          value = 0,
          min = 0,
          max = 3,
          step = 1
        )
      )
    )
  )
)

xy_menu <- conditionalPanel(
  condition = "input.nfiles >= 2",
  fluidRow(
    h4("2D plots Menu:"),
    column(
      4,
      checkboxInput(
        "show_scatterplot",
        label = "Show Scatter plot",
        value = FALSE
      ),
      conditionalPanel(
        condition = "input.show_scatterplot",
        checkboxInput(
          "xy_normalize",
          label = "Normalize XY",
          value = FALSE
        ),
        checkboxInput(
          "add_density",
          label = "Add Density",
          value = FALSE
        ),
        downloadButton("xydata", "Density data"),
      )
    ),
    conditionalPanel(
      condition = "input.show_scatterplot",
      column(
        8,
        sliderInput(
          "resample",
          label = "Sampling proportion",
          value = 0.05,
          min = 0,
          max = 1,
          step = 0.05
        ),
        conditionalPanel(
          condition = "input.add_density",
          sliderInput(
            "densitybins",
            label = "Number of bins",
            value = 25,
            min = 25,
            max = 150,
            step = 5
          ),
          sliderInput(
            "densitybox",
            label = "Box size for region selection",
            value = 0,
            min = 0,
            max = 0.25,
            step = 0.05
          )
        )
      ),
      column(
        12,
        uiOutput("stream_selectors")
      )
    )
  )
)

ui <- pageWithSidebar(
  h2("Coorelative data analysis tool"),
  sidebarPanel(
    notes,
    files,
    histogram_menu,
    xy_menu
  ),
  mainPanel(
    plotOutput("file_preview"),
    conditionalPanel(
      condition = "input.show_histogram",
      plotOutput("histograms")
    ),
    conditionalPanel(
      condition = "input.show_scatterplot | input.add_density",
      plotOutput("xyplot", height = 600)
    )
  )
)